.. :changelog:

History
-------

0.1.8 (2023-02-02)
++++++++++++++++++

* Add Django 4 compatibility

0.1.7 (2022-10-11)
++++++++++++++++++

* Add samesite configuration option


0.1.6 (2022-01-31)
++++++++++++++++++

* Simplify banner text to prevent fails

DEPRECATION WARNING:

* The setting variable `policy_link` was removed due to errors. Please handle any text/link combinations yourself.


0.1.5 (2021-02-15)
++++++++++++++++++

* Add plain html support for the groups labels


0.1.4 (2020-05-13)
++++++++++++++++++

* Improve backward compatibility of browsers


0.1.3 (2020-05-13)
++++++++++++++++++

* Fix translation issue in banner text


0.1.2 (2020-04-09)
++++++++++++++++++

* Bugfix


0.1.1 (2020-04-08)
++++++++++++++++++

* Bugfix


0.1.0 (2019-10-16)
++++++++++++++++++

* First release on PyPI.
